<a id="mypy-boto3-sagemaker"></a>

# mypy-boto3-sagemaker

[![PyPI - types-aiobotocore-sagemaker](https://img.shields.io/pypi/v/types-aiobotocore-sagemaker.svg?color=blue)](https://pypi.org/project/types-aiobotocore-sagemaker)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-sagemaker.svg?color=blue)](https://pypi.org/project/types-aiobotocore-sagemaker)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-sagemaker?color=blue)](https://pypistats.org/packages/types-aiobotocore-sagemaker)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.SageMaker 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker.html#SageMaker)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-sagemaker docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-sagemaker](#mypy-boto3-sagemaker)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `SageMaker`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `SageMaker` service.

```bash
python -m pip install types-aiobotocore[sagemaker]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[sagemaker]` in your environment:
  `python -m pip install 'types-aiobotocore[sagemaker]'`

Both type checking and auto-complete should work for `SageMaker` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[sagemaker]` in your environment:
  `python -m pip install 'types-aiobotocore[sagemaker]'`

Both type checking and auto-complete should work for `SageMaker` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[sagemaker]` in your environment:
  `python -m pip install 'types-aiobotocore[sagemaker]'`
- Run `mypy` as usual

Type checking should work for `SageMaker` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[sagemaker]` in your environment:
  `python -m pip install 'types-aiobotocore[sagemaker]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `SageMaker` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`SageMakerClient` provides annotations for
`session.create_client("sagemaker")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_sagemaker import SageMakerClient

session = get_session()
with async session.create_client("sagemaker") as client:
    client: SageMakerClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_sagemaker.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_sagemaker import SageMakerClient
from types_aiobotocore_sagemaker.paginator import (
    ListActionsPaginator,
    ListAlgorithmsPaginator,
    ListAppImageConfigsPaginator,
    ListAppsPaginator,
    ListArtifactsPaginator,
    ListAssociationsPaginator,
    ListAutoMLJobsPaginator,
    ListCandidatesForAutoMLJobPaginator,
    ListCodeRepositoriesPaginator,
    ListCompilationJobsPaginator,
    ListContextsPaginator,
    ListDataQualityJobDefinitionsPaginator,
    ListDeviceFleetsPaginator,
    ListDevicesPaginator,
    ListDomainsPaginator,
    ListEdgePackagingJobsPaginator,
    ListEndpointConfigsPaginator,
    ListEndpointsPaginator,
    ListExperimentsPaginator,
    ListFeatureGroupsPaginator,
    ListFlowDefinitionsPaginator,
    ListHumanTaskUisPaginator,
    ListHyperParameterTuningJobsPaginator,
    ListImageVersionsPaginator,
    ListImagesPaginator,
    ListInferenceRecommendationsJobsPaginator,
    ListLabelingJobsPaginator,
    ListLabelingJobsForWorkteamPaginator,
    ListLineageGroupsPaginator,
    ListModelBiasJobDefinitionsPaginator,
    ListModelExplainabilityJobDefinitionsPaginator,
    ListModelMetadataPaginator,
    ListModelPackageGroupsPaginator,
    ListModelPackagesPaginator,
    ListModelQualityJobDefinitionsPaginator,
    ListModelsPaginator,
    ListMonitoringExecutionsPaginator,
    ListMonitoringSchedulesPaginator,
    ListNotebookInstanceLifecycleConfigsPaginator,
    ListNotebookInstancesPaginator,
    ListPipelineExecutionStepsPaginator,
    ListPipelineExecutionsPaginator,
    ListPipelineParametersForExecutionPaginator,
    ListPipelinesPaginator,
    ListProcessingJobsPaginator,
    ListStudioLifecycleConfigsPaginator,
    ListSubscribedWorkteamsPaginator,
    ListTagsPaginator,
    ListTrainingJobsPaginator,
    ListTrainingJobsForHyperParameterTuningJobPaginator,
    ListTransformJobsPaginator,
    ListTrialComponentsPaginator,
    ListTrialsPaginator,
    ListUserProfilesPaginator,
    ListWorkforcesPaginator,
    ListWorkteamsPaginator,
    SearchPaginator,
)

session = get_session()
with async session.create_client("sagemaker") as client:
    client: SageMakerClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_actions_paginator: ListActionsPaginator = client.get_paginator("list_actions")
        list_algorithms_paginator: ListAlgorithmsPaginator = client.get_paginator("list_algorithms")
        list_app_image_configs_paginator: ListAppImageConfigsPaginator = client.get_paginator("list_app_image_configs")
        list_apps_paginator: ListAppsPaginator = client.get_paginator("list_apps")
        list_artifacts_paginator: ListArtifactsPaginator = client.get_paginator("list_artifacts")
        list_associations_paginator: ListAssociationsPaginator = client.get_paginator("list_associations")
        list_auto_ml_jobs_paginator: ListAutoMLJobsPaginator = client.get_paginator("list_auto_ml_jobs")
        list_candidates_for_auto_ml_job_paginator: ListCandidatesForAutoMLJobPaginator = client.get_paginator("list_candidates_for_auto_ml_job")
        list_code_repositories_paginator: ListCodeRepositoriesPaginator = client.get_paginator("list_code_repositories")
        list_compilation_jobs_paginator: ListCompilationJobsPaginator = client.get_paginator("list_compilation_jobs")
        list_contexts_paginator: ListContextsPaginator = client.get_paginator("list_contexts")
        list_data_quality_job_definitions_paginator: ListDataQualityJobDefinitionsPaginator = client.get_paginator("list_data_quality_job_definitions")
        list_device_fleets_paginator: ListDeviceFleetsPaginator = client.get_paginator("list_device_fleets")
        list_devices_paginator: ListDevicesPaginator = client.get_paginator("list_devices")
        list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
        list_edge_packaging_jobs_paginator: ListEdgePackagingJobsPaginator = client.get_paginator("list_edge_packaging_jobs")
        list_endpoint_configs_paginator: ListEndpointConfigsPaginator = client.get_paginator("list_endpoint_configs")
        list_endpoints_paginator: ListEndpointsPaginator = client.get_paginator("list_endpoints")
        list_experiments_paginator: ListExperimentsPaginator = client.get_paginator("list_experiments")
        list_feature_groups_paginator: ListFeatureGroupsPaginator = client.get_paginator("list_feature_groups")
        list_flow_definitions_paginator: ListFlowDefinitionsPaginator = client.get_paginator("list_flow_definitions")
        list_human_task_uis_paginator: ListHumanTaskUisPaginator = client.get_paginator("list_human_task_uis")
        list_hyper_parameter_tuning_jobs_paginator: ListHyperParameterTuningJobsPaginator = client.get_paginator("list_hyper_parameter_tuning_jobs")
        list_image_versions_paginator: ListImageVersionsPaginator = client.get_paginator("list_image_versions")
        list_images_paginator: ListImagesPaginator = client.get_paginator("list_images")
        list_inference_recommendations_jobs_paginator: ListInferenceRecommendationsJobsPaginator = client.get_paginator("list_inference_recommendations_jobs")
        list_labeling_jobs_paginator: ListLabelingJobsPaginator = client.get_paginator("list_labeling_jobs")
        list_labeling_jobs_for_workteam_paginator: ListLabelingJobsForWorkteamPaginator = client.get_paginator("list_labeling_jobs_for_workteam")
        list_lineage_groups_paginator: ListLineageGroupsPaginator = client.get_paginator("list_lineage_groups")
        list_model_bias_job_definitions_paginator: ListModelBiasJobDefinitionsPaginator = client.get_paginator("list_model_bias_job_definitions")
        list_model_explainability_job_definitions_paginator: ListModelExplainabilityJobDefinitionsPaginator = client.get_paginator("list_model_explainability_job_definitions")
        list_model_metadata_paginator: ListModelMetadataPaginator = client.get_paginator("list_model_metadata")
        list_model_package_groups_paginator: ListModelPackageGroupsPaginator = client.get_paginator("list_model_package_groups")
        list_model_packages_paginator: ListModelPackagesPaginator = client.get_paginator("list_model_packages")
        list_model_quality_job_definitions_paginator: ListModelQualityJobDefinitionsPaginator = client.get_paginator("list_model_quality_job_definitions")
        list_models_paginator: ListModelsPaginator = client.get_paginator("list_models")
        list_monitoring_executions_paginator: ListMonitoringExecutionsPaginator = client.get_paginator("list_monitoring_executions")
        list_monitoring_schedules_paginator: ListMonitoringSchedulesPaginator = client.get_paginator("list_monitoring_schedules")
        list_notebook_instance_lifecycle_configs_paginator: ListNotebookInstanceLifecycleConfigsPaginator = client.get_paginator("list_notebook_instance_lifecycle_configs")
        list_notebook_instances_paginator: ListNotebookInstancesPaginator = client.get_paginator("list_notebook_instances")
        list_pipeline_execution_steps_paginator: ListPipelineExecutionStepsPaginator = client.get_paginator("list_pipeline_execution_steps")
        list_pipeline_executions_paginator: ListPipelineExecutionsPaginator = client.get_paginator("list_pipeline_executions")
        list_pipeline_parameters_for_execution_paginator: ListPipelineParametersForExecutionPaginator = client.get_paginator("list_pipeline_parameters_for_execution")
        list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
        list_processing_jobs_paginator: ListProcessingJobsPaginator = client.get_paginator("list_processing_jobs")
        list_studio_lifecycle_configs_paginator: ListStudioLifecycleConfigsPaginator = client.get_paginator("list_studio_lifecycle_configs")
        list_subscribed_workteams_paginator: ListSubscribedWorkteamsPaginator = client.get_paginator("list_subscribed_workteams")
        list_tags_paginator: ListTagsPaginator = client.get_paginator("list_tags")
        list_training_jobs_paginator: ListTrainingJobsPaginator = client.get_paginator("list_training_jobs")
        list_training_jobs_for_hyper_parameter_tuning_job_paginator: ListTrainingJobsForHyperParameterTuningJobPaginator = client.get_paginator("list_training_jobs_for_hyper_parameter_tuning_job")
        list_transform_jobs_paginator: ListTransformJobsPaginator = client.get_paginator("list_transform_jobs")
        list_trial_components_paginator: ListTrialComponentsPaginator = client.get_paginator("list_trial_components")
        list_trials_paginator: ListTrialsPaginator = client.get_paginator("list_trials")
        list_user_profiles_paginator: ListUserProfilesPaginator = client.get_paginator("list_user_profiles")
        list_workforces_paginator: ListWorkforcesPaginator = client.get_paginator("list_workforces")
        list_workteams_paginator: ListWorkteamsPaginator = client.get_paginator("list_workteams")
        search_paginator: SearchPaginator = client.get_paginator("search")
    ```


### Waiters annotations

`types_aiobotocore_sagemaker.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_sagemaker.client import SageMakerClient
from types_aiobotocore_sagemaker.waiter import (
    EndpointDeletedWaiter,
    EndpointInServiceWaiter,
    ImageCreatedWaiter,
    ImageDeletedWaiter,
    ImageUpdatedWaiter,
    ImageVersionCreatedWaiter,
    ImageVersionDeletedWaiter,
    NotebookInstanceDeletedWaiter,
    NotebookInstanceInServiceWaiter,
    NotebookInstanceStoppedWaiter,
    ProcessingJobCompletedOrStoppedWaiter,
    TrainingJobCompletedOrStoppedWaiter,
    TransformJobCompletedOrStoppedWaiter,
)

session = get_session()
with async session.create_client("sagemaker") as client:
    client: SageMakerClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        endpoint_deleted_waiter: EndpointDeletedWaiter = client.get_waiter("endpoint_deleted")
        endpoint_in_service_waiter: EndpointInServiceWaiter = client.get_waiter("endpoint_in_service")
        image_created_waiter: ImageCreatedWaiter = client.get_waiter("image_created")
        image_deleted_waiter: ImageDeletedWaiter = client.get_waiter("image_deleted")
        image_updated_waiter: ImageUpdatedWaiter = client.get_waiter("image_updated")
        image_version_created_waiter: ImageVersionCreatedWaiter = client.get_waiter("image_version_created")
        image_version_deleted_waiter: ImageVersionDeletedWaiter = client.get_waiter("image_version_deleted")
        notebook_instance_deleted_waiter: NotebookInstanceDeletedWaiter = client.get_waiter("notebook_instance_deleted")
        notebook_instance_in_service_waiter: NotebookInstanceInServiceWaiter = client.get_waiter("notebook_instance_in_service")
        notebook_instance_stopped_waiter: NotebookInstanceStoppedWaiter = client.get_waiter("notebook_instance_stopped")
        processing_job_completed_or_stopped_waiter: ProcessingJobCompletedOrStoppedWaiter = client.get_waiter("processing_job_completed_or_stopped")
        training_job_completed_or_stopped_waiter: TrainingJobCompletedOrStoppedWaiter = client.get_waiter("training_job_completed_or_stopped")
        transform_job_completed_or_stopped_waiter: TransformJobCompletedOrStoppedWaiter = client.get_waiter("transform_job_completed_or_stopped")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_sagemaker.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_sagemaker.literals import (
    ActionStatusType,
    AlgorithmSortByType,
    AlgorithmStatusType,
    AppImageConfigSortKeyType,
    AppInstanceTypeType,
    AppNetworkAccessTypeType,
    AppSecurityGroupManagementType,
    AppSortKeyType,
    AppStatusType,
    AppTypeType,
    ArtifactSourceIdTypeType,
    AssemblyTypeType,
    AssociationEdgeTypeType,
    AthenaResultCompressionTypeType,
    AthenaResultFormatType,
    AuthModeType,
    AutoMLJobObjectiveTypeType,
    AutoMLJobSecondaryStatusType,
    AutoMLJobStatusType,
    AutoMLMetricEnumType,
    AutoMLS3DataTypeType,
    AutoMLSortByType,
    AutoMLSortOrderType,
    AwsManagedHumanLoopRequestSourceType,
    BatchStrategyType,
    BooleanOperatorType,
    CandidateSortByType,
    CandidateStatusType,
    CandidateStepTypeType,
    CapacitySizeTypeType,
    CaptureModeType,
    CaptureStatusType,
    CodeRepositorySortByType,
    CodeRepositorySortOrderType,
    CompilationJobStatusType,
    CompressionTypeType,
    ConditionOutcomeType,
    ContainerModeType,
    ContentClassifierType,
    DataDistributionTypeType,
    DetailedAlgorithmStatusType,
    DetailedModelPackageStatusType,
    DirectInternetAccessType,
    DirectionType,
    DomainStatusType,
    EdgePackagingJobStatusType,
    EdgePresetDeploymentStatusType,
    EdgePresetDeploymentTypeType,
    EndpointConfigSortKeyType,
    EndpointDeletedWaiterName,
    EndpointInServiceWaiterName,
    EndpointSortKeyType,
    EndpointStatusType,
    ExecutionStatusType,
    FeatureGroupSortByType,
    FeatureGroupSortOrderType,
    FeatureGroupStatusType,
    FeatureTypeType,
    FileSystemAccessModeType,
    FileSystemTypeType,
    FlowDefinitionStatusType,
    FrameworkType,
    HumanTaskUiStatusType,
    HyperParameterScalingTypeType,
    HyperParameterTuningJobObjectiveTypeType,
    HyperParameterTuningJobSortByOptionsType,
    HyperParameterTuningJobStatusType,
    HyperParameterTuningJobStrategyTypeType,
    HyperParameterTuningJobWarmStartTypeType,
    ImageCreatedWaiterName,
    ImageDeletedWaiterName,
    ImageSortByType,
    ImageSortOrderType,
    ImageStatusType,
    ImageUpdatedWaiterName,
    ImageVersionCreatedWaiterName,
    ImageVersionDeletedWaiterName,
    ImageVersionSortByType,
    ImageVersionSortOrderType,
    ImageVersionStatusType,
    InferenceExecutionModeType,
    InputModeType,
    InstanceTypeType,
    JoinSourceType,
    LabelingJobStatusType,
    LineageTypeType,
    ListActionsPaginatorName,
    ListAlgorithmsPaginatorName,
    ListAppImageConfigsPaginatorName,
    ListAppsPaginatorName,
    ListArtifactsPaginatorName,
    ListAssociationsPaginatorName,
    ListAutoMLJobsPaginatorName,
    ListCandidatesForAutoMLJobPaginatorName,
    ListCodeRepositoriesPaginatorName,
    ListCompilationJobsPaginatorName,
    ListCompilationJobsSortByType,
    ListContextsPaginatorName,
    ListDataQualityJobDefinitionsPaginatorName,
    ListDeviceFleetsPaginatorName,
    ListDeviceFleetsSortByType,
    ListDevicesPaginatorName,
    ListDomainsPaginatorName,
    ListEdgePackagingJobsPaginatorName,
    ListEdgePackagingJobsSortByType,
    ListEndpointConfigsPaginatorName,
    ListEndpointsPaginatorName,
    ListExperimentsPaginatorName,
    ListFeatureGroupsPaginatorName,
    ListFlowDefinitionsPaginatorName,
    ListHumanTaskUisPaginatorName,
    ListHyperParameterTuningJobsPaginatorName,
    ListImageVersionsPaginatorName,
    ListImagesPaginatorName,
    ListInferenceRecommendationsJobsPaginatorName,
    ListInferenceRecommendationsJobsSortByType,
    ListLabelingJobsForWorkteamPaginatorName,
    ListLabelingJobsForWorkteamSortByOptionsType,
    ListLabelingJobsPaginatorName,
    ListLineageGroupsPaginatorName,
    ListModelBiasJobDefinitionsPaginatorName,
    ListModelExplainabilityJobDefinitionsPaginatorName,
    ListModelMetadataPaginatorName,
    ListModelPackageGroupsPaginatorName,
    ListModelPackagesPaginatorName,
    ListModelQualityJobDefinitionsPaginatorName,
    ListModelsPaginatorName,
    ListMonitoringExecutionsPaginatorName,
    ListMonitoringSchedulesPaginatorName,
    ListNotebookInstanceLifecycleConfigsPaginatorName,
    ListNotebookInstancesPaginatorName,
    ListPipelineExecutionStepsPaginatorName,
    ListPipelineExecutionsPaginatorName,
    ListPipelineParametersForExecutionPaginatorName,
    ListPipelinesPaginatorName,
    ListProcessingJobsPaginatorName,
    ListStudioLifecycleConfigsPaginatorName,
    ListSubscribedWorkteamsPaginatorName,
    ListTagsPaginatorName,
    ListTrainingJobsForHyperParameterTuningJobPaginatorName,
    ListTrainingJobsPaginatorName,
    ListTransformJobsPaginatorName,
    ListTrialComponentsPaginatorName,
    ListTrialsPaginatorName,
    ListUserProfilesPaginatorName,
    ListWorkforcesPaginatorName,
    ListWorkforcesSortByOptionsType,
    ListWorkteamsPaginatorName,
    ListWorkteamsSortByOptionsType,
    MetricSetSourceType,
    ModelApprovalStatusType,
    ModelCacheSettingType,
    ModelMetadataFilterTypeType,
    ModelPackageGroupSortByType,
    ModelPackageGroupStatusType,
    ModelPackageSortByType,
    ModelPackageStatusType,
    ModelPackageTypeType,
    ModelSortKeyType,
    MonitoringExecutionSortKeyType,
    MonitoringJobDefinitionSortKeyType,
    MonitoringProblemTypeType,
    MonitoringScheduleSortKeyType,
    MonitoringTypeType,
    NotebookInstanceAcceleratorTypeType,
    NotebookInstanceDeletedWaiterName,
    NotebookInstanceInServiceWaiterName,
    NotebookInstanceLifecycleConfigSortKeyType,
    NotebookInstanceLifecycleConfigSortOrderType,
    NotebookInstanceSortKeyType,
    NotebookInstanceSortOrderType,
    NotebookInstanceStatusType,
    NotebookInstanceStoppedWaiterName,
    NotebookOutputOptionType,
    ObjectiveStatusType,
    OfflineStoreStatusValueType,
    OperatorType,
    OrderKeyType,
    ParameterTypeType,
    PipelineExecutionStatusType,
    PipelineStatusType,
    ProblemTypeType,
    ProcessingInstanceTypeType,
    ProcessingJobCompletedOrStoppedWaiterName,
    ProcessingJobStatusType,
    ProcessingS3CompressionTypeType,
    ProcessingS3DataDistributionTypeType,
    ProcessingS3DataTypeType,
    ProcessingS3InputModeType,
    ProcessingS3UploadModeType,
    ProductionVariantAcceleratorTypeType,
    ProductionVariantInstanceTypeType,
    ProfilingStatusType,
    ProjectSortByType,
    ProjectSortOrderType,
    ProjectStatusType,
    RStudioServerProAccessStatusType,
    RStudioServerProUserGroupType,
    RecommendationJobStatusType,
    RecommendationJobTypeType,
    RecordWrapperType,
    RedshiftResultCompressionTypeType,
    RedshiftResultFormatType,
    RepositoryAccessModeType,
    ResourceTypeType,
    RetentionTypeType,
    RootAccessType,
    RuleEvaluationStatusType,
    S3DataDistributionType,
    S3DataTypeType,
    SagemakerServicecatalogStatusType,
    ScheduleStatusType,
    SearchPaginatorName,
    SearchSortOrderType,
    SecondaryStatusType,
    SortActionsByType,
    SortArtifactsByType,
    SortAssociationsByType,
    SortByType,
    SortContextsByType,
    SortExperimentsByType,
    SortLineageGroupsByType,
    SortOrderType,
    SortPipelineExecutionsByType,
    SortPipelinesByType,
    SortTrialComponentsByType,
    SortTrialsByType,
    SplitTypeType,
    StepStatusType,
    StudioLifecycleConfigAppTypeType,
    StudioLifecycleConfigSortKeyType,
    TargetDeviceType,
    TargetPlatformAcceleratorType,
    TargetPlatformArchType,
    TargetPlatformOsType,
    TrafficRoutingConfigTypeType,
    TrafficTypeType,
    TrainingInputModeType,
    TrainingInstanceTypeType,
    TrainingJobCompletedOrStoppedWaiterName,
    TrainingJobEarlyStoppingTypeType,
    TrainingJobSortByOptionsType,
    TrainingJobStatusType,
    TransformInstanceTypeType,
    TransformJobCompletedOrStoppedWaiterName,
    TransformJobStatusType,
    TrialComponentPrimaryStatusType,
    UserProfileSortKeyType,
    UserProfileStatusType,
    VariantPropertyTypeType,
    VariantStatusType,
    ServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: ActionStatusType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_sagemaker.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_sagemaker.type_defs import (
    ActionSourceTypeDef,
    ActionSummaryTypeDef,
    AddAssociationRequestRequestTypeDef,
    AddAssociationResponseTypeDef,
    AddTagsInputRequestTypeDef,
    AddTagsOutputTypeDef,
    AdditionalInferenceSpecificationDefinitionTypeDef,
    AgentVersionTypeDef,
    AlarmTypeDef,
    AlgorithmSpecificationTypeDef,
    AlgorithmStatusDetailsTypeDef,
    AlgorithmStatusItemTypeDef,
    AlgorithmSummaryTypeDef,
    AlgorithmValidationProfileTypeDef,
    AlgorithmValidationSpecificationTypeDef,
    AnnotationConsolidationConfigTypeDef,
    AppDetailsTypeDef,
    AppImageConfigDetailsTypeDef,
    AppSpecificationTypeDef,
    ArtifactSourceTypeDef,
    ArtifactSourceTypeTypeDef,
    ArtifactSummaryTypeDef,
    AssociateTrialComponentRequestRequestTypeDef,
    AssociateTrialComponentResponseTypeDef,
    AssociationSummaryTypeDef,
    AsyncInferenceClientConfigTypeDef,
    AsyncInferenceConfigTypeDef,
    AsyncInferenceNotificationConfigTypeDef,
    AsyncInferenceOutputConfigTypeDef,
    AthenaDatasetDefinitionTypeDef,
    AutoMLCandidateStepTypeDef,
    AutoMLCandidateTypeDef,
    AutoMLChannelTypeDef,
    AutoMLContainerDefinitionTypeDef,
    AutoMLDataSourceTypeDef,
    AutoMLJobArtifactsTypeDef,
    AutoMLJobCompletionCriteriaTypeDef,
    AutoMLJobConfigTypeDef,
    AutoMLJobObjectiveTypeDef,
    AutoMLJobSummaryTypeDef,
    AutoMLOutputDataConfigTypeDef,
    AutoMLPartialFailureReasonTypeDef,
    AutoMLS3DataSourceTypeDef,
    AutoMLSecurityConfigTypeDef,
    AutoRollbackConfigTypeDef,
    BatchDescribeModelPackageErrorTypeDef,
    BatchDescribeModelPackageInputRequestTypeDef,
    BatchDescribeModelPackageOutputTypeDef,
    BatchDescribeModelPackageSummaryTypeDef,
    BiasTypeDef,
    BlueGreenUpdatePolicyTypeDef,
    CacheHitResultTypeDef,
    CallbackStepMetadataTypeDef,
    CandidateArtifactLocationsTypeDef,
    CandidatePropertiesTypeDef,
    CapacitySizeTypeDef,
    CaptureContentTypeHeaderTypeDef,
    CaptureOptionTypeDef,
    CategoricalParameterRangeSpecificationTypeDef,
    CategoricalParameterRangeTypeDef,
    CategoricalParameterTypeDef,
    ChannelSpecificationTypeDef,
    ChannelTypeDef,
    CheckpointConfigTypeDef,
    ClarifyCheckStepMetadataTypeDef,
    CodeRepositorySummaryTypeDef,
    CognitoConfigTypeDef,
    CognitoMemberDefinitionTypeDef,
    CollectionConfigurationTypeDef,
    CompilationJobSummaryTypeDef,
    ConditionStepMetadataTypeDef,
    ContainerDefinitionTypeDef,
    ContextSourceTypeDef,
    ContextSummaryTypeDef,
    ContinuousParameterRangeSpecificationTypeDef,
    ContinuousParameterRangeTypeDef,
    CreateActionRequestRequestTypeDef,
    CreateActionResponseTypeDef,
    CreateAlgorithmInputRequestTypeDef,
    CreateAlgorithmOutputTypeDef,
    CreateAppImageConfigRequestRequestTypeDef,
    CreateAppImageConfigResponseTypeDef,
    CreateAppRequestRequestTypeDef,
    CreateAppResponseTypeDef,
    CreateArtifactRequestRequestTypeDef,
    CreateArtifactResponseTypeDef,
    CreateAutoMLJobRequestRequestTypeDef,
    CreateAutoMLJobResponseTypeDef,
    CreateCodeRepositoryInputRequestTypeDef,
    CreateCodeRepositoryOutputTypeDef,
    CreateCompilationJobRequestRequestTypeDef,
    CreateCompilationJobResponseTypeDef,
    CreateContextRequestRequestTypeDef,
    CreateContextResponseTypeDef,
    CreateDataQualityJobDefinitionRequestRequestTypeDef,
    CreateDataQualityJobDefinitionResponseTypeDef,
    CreateDeviceFleetRequestRequestTypeDef,
    CreateDomainRequestRequestTypeDef,
    CreateDomainResponseTypeDef,
    CreateEdgePackagingJobRequestRequestTypeDef,
    CreateEndpointConfigInputRequestTypeDef,
    CreateEndpointConfigOutputTypeDef,
    CreateEndpointInputRequestTypeDef,
    CreateEndpointOutputTypeDef,
    CreateExperimentRequestRequestTypeDef,
    CreateExperimentResponseTypeDef,
    CreateFeatureGroupRequestRequestTypeDef,
    CreateFeatureGroupResponseTypeDef,
    CreateFlowDefinitionRequestRequestTypeDef,
    CreateFlowDefinitionResponseTypeDef,
    CreateHumanTaskUiRequestRequestTypeDef,
    CreateHumanTaskUiResponseTypeDef,
    CreateHyperParameterTuningJobRequestRequestTypeDef,
    CreateHyperParameterTuningJobResponseTypeDef,
    CreateImageRequestRequestTypeDef,
    CreateImageResponseTypeDef,
    CreateImageVersionRequestRequestTypeDef,
    CreateImageVersionResponseTypeDef,
    CreateInferenceRecommendationsJobRequestRequestTypeDef,
    CreateInferenceRecommendationsJobResponseTypeDef,
    CreateLabelingJobRequestRequestTypeDef,
    CreateLabelingJobResponseTypeDef,
    CreateModelBiasJobDefinitionRequestRequestTypeDef,
    CreateModelBiasJobDefinitionResponseTypeDef,
    CreateModelExplainabilityJobDefinitionRequestRequestTypeDef,
    CreateModelExplainabilityJobDefinitionResponseTypeDef,
    CreateModelInputRequestTypeDef,
    CreateModelOutputTypeDef,
    CreateModelPackageGroupInputRequestTypeDef,
    CreateModelPackageGroupOutputTypeDef,
    CreateModelPackageInputRequestTypeDef,
    CreateModelPackageOutputTypeDef,
    CreateModelQualityJobDefinitionRequestRequestTypeDef,
    CreateModelQualityJobDefinitionResponseTypeDef,
    CreateMonitoringScheduleRequestRequestTypeDef,
    CreateMonitoringScheduleResponseTypeDef,
    CreateNotebookInstanceInputRequestTypeDef,
    CreateNotebookInstanceLifecycleConfigInputRequestTypeDef,
    CreateNotebookInstanceLifecycleConfigOutputTypeDef,
    CreateNotebookInstanceOutputTypeDef,
    CreatePipelineRequestRequestTypeDef,
    CreatePipelineResponseTypeDef,
    CreatePresignedDomainUrlRequestRequestTypeDef,
    CreatePresignedDomainUrlResponseTypeDef,
    CreatePresignedNotebookInstanceUrlInputRequestTypeDef,
    CreatePresignedNotebookInstanceUrlOutputTypeDef,
    CreateProcessingJobRequestRequestTypeDef,
    CreateProcessingJobResponseTypeDef,
    CreateProjectInputRequestTypeDef,
    CreateProjectOutputTypeDef,
    CreateStudioLifecycleConfigRequestRequestTypeDef,
    CreateStudioLifecycleConfigResponseTypeDef,
    CreateTrainingJobRequestRequestTypeDef,
    CreateTrainingJobResponseTypeDef,
    CreateTransformJobRequestRequestTypeDef,
    CreateTransformJobResponseTypeDef,
    CreateTrialComponentRequestRequestTypeDef,
    CreateTrialComponentResponseTypeDef,
    CreateTrialRequestRequestTypeDef,
    CreateTrialResponseTypeDef,
    CreateUserProfileRequestRequestTypeDef,
    CreateUserProfileResponseTypeDef,
    CreateWorkforceRequestRequestTypeDef,
    CreateWorkforceResponseTypeDef,
    CreateWorkteamRequestRequestTypeDef,
    CreateWorkteamResponseTypeDef,
    CustomImageTypeDef,
    DataCaptureConfigSummaryTypeDef,
    DataCaptureConfigTypeDef,
    DataCatalogConfigTypeDef,
    DataProcessingTypeDef,
    DataQualityAppSpecificationTypeDef,
    DataQualityBaselineConfigTypeDef,
    DataQualityJobInputTypeDef,
    DataSourceTypeDef,
    DatasetDefinitionTypeDef,
    DebugHookConfigTypeDef,
    DebugRuleConfigurationTypeDef,
    DebugRuleEvaluationStatusTypeDef,
    DeleteActionRequestRequestTypeDef,
    DeleteActionResponseTypeDef,
    DeleteAlgorithmInputRequestTypeDef,
    DeleteAppImageConfigRequestRequestTypeDef,
    DeleteAppRequestRequestTypeDef,
    DeleteArtifactRequestRequestTypeDef,
    DeleteArtifactResponseTypeDef,
    DeleteAssociationRequestRequestTypeDef,
    DeleteAssociationResponseTypeDef,
    DeleteCodeRepositoryInputRequestTypeDef,
    DeleteContextRequestRequestTypeDef,
    DeleteContextResponseTypeDef,
    DeleteDataQualityJobDefinitionRequestRequestTypeDef,
    DeleteDeviceFleetRequestRequestTypeDef,
    DeleteDomainRequestRequestTypeDef,
    DeleteEndpointConfigInputRequestTypeDef,
    DeleteEndpointInputRequestTypeDef,
    DeleteExperimentRequestRequestTypeDef,
    DeleteExperimentResponseTypeDef,
    DeleteFeatureGroupRequestRequestTypeDef,
    DeleteFlowDefinitionRequestRequestTypeDef,
    DeleteHumanTaskUiRequestRequestTypeDef,
    DeleteImageRequestRequestTypeDef,
    DeleteImageVersionRequestRequestTypeDef,
    DeleteModelBiasJobDefinitionRequestRequestTypeDef,
    DeleteModelExplainabilityJobDefinitionRequestRequestTypeDef,
    DeleteModelInputRequestTypeDef,
    DeleteModelPackageGroupInputRequestTypeDef,
    DeleteModelPackageGroupPolicyInputRequestTypeDef,
    DeleteModelPackageInputRequestTypeDef,
    DeleteModelQualityJobDefinitionRequestRequestTypeDef,
    DeleteMonitoringScheduleRequestRequestTypeDef,
    DeleteNotebookInstanceInputRequestTypeDef,
    DeleteNotebookInstanceLifecycleConfigInputRequestTypeDef,
    DeletePipelineRequestRequestTypeDef,
    DeletePipelineResponseTypeDef,
    DeleteProjectInputRequestTypeDef,
    DeleteStudioLifecycleConfigRequestRequestTypeDef,
    DeleteTagsInputRequestTypeDef,
    DeleteTrialComponentRequestRequestTypeDef,
    DeleteTrialComponentResponseTypeDef,
    DeleteTrialRequestRequestTypeDef,
    DeleteTrialResponseTypeDef,
    DeleteUserProfileRequestRequestTypeDef,
    DeleteWorkforceRequestRequestTypeDef,
    DeleteWorkteamRequestRequestTypeDef,
    DeleteWorkteamResponseTypeDef,
    DeployedImageTypeDef,
    DeploymentConfigTypeDef,
    DeregisterDevicesRequestRequestTypeDef,
    DescribeActionRequestRequestTypeDef,
    DescribeActionResponseTypeDef,
    DescribeAlgorithmInputRequestTypeDef,
    DescribeAlgorithmOutputTypeDef,
    DescribeAppImageConfigRequestRequestTypeDef,
    DescribeAppImageConfigResponseTypeDef,
    DescribeAppRequestRequestTypeDef,
    DescribeAppResponseTypeDef,
    DescribeArtifactRequestRequestTypeDef,
    DescribeArtifactResponseTypeDef,
    DescribeAutoMLJobRequestRequestTypeDef,
    DescribeAutoMLJobResponseTypeDef,
    DescribeCodeRepositoryInputRequestTypeDef,
    DescribeCodeRepositoryOutputTypeDef,
    DescribeCompilationJobRequestRequestTypeDef,
    DescribeCompilationJobResponseTypeDef,
    DescribeContextRequestRequestTypeDef,
    DescribeContextResponseTypeDef,
    DescribeDataQualityJobDefinitionRequestRequestTypeDef,
    DescribeDataQualityJobDefinitionResponseTypeDef,
    DescribeDeviceFleetRequestRequestTypeDef,
    DescribeDeviceFleetResponseTypeDef,
    DescribeDeviceRequestRequestTypeDef,
    DescribeDeviceResponseTypeDef,
    DescribeDomainRequestRequestTypeDef,
    DescribeDomainResponseTypeDef,
    DescribeEdgePackagingJobRequestRequestTypeDef,
    DescribeEdgePackagingJobResponseTypeDef,
    DescribeEndpointConfigInputRequestTypeDef,
    DescribeEndpointConfigOutputTypeDef,
    DescribeEndpointInputRequestTypeDef,
    DescribeEndpointOutputTypeDef,
    DescribeExperimentRequestRequestTypeDef,
    DescribeExperimentResponseTypeDef,
    DescribeFeatureGroupRequestRequestTypeDef,
    DescribeFeatureGroupResponseTypeDef,
    DescribeFlowDefinitionRequestRequestTypeDef,
    DescribeFlowDefinitionResponseTypeDef,
    DescribeHumanTaskUiRequestRequestTypeDef,
    DescribeHumanTaskUiResponseTypeDef,
    DescribeHyperParameterTuningJobRequestRequestTypeDef,
    DescribeHyperParameterTuningJobResponseTypeDef,
    DescribeImageRequestRequestTypeDef,
    DescribeImageResponseTypeDef,
    DescribeImageVersionRequestRequestTypeDef,
    DescribeImageVersionResponseTypeDef,
    DescribeInferenceRecommendationsJobRequestRequestTypeDef,
    DescribeInferenceRecommendationsJobResponseTypeDef,
    DescribeLabelingJobRequestRequestTypeDef,
    DescribeLabelingJobResponseTypeDef,
    DescribeLineageGroupRequestRequestTypeDef,
    DescribeLineageGroupResponseTypeDef,
    DescribeModelBiasJobDefinitionRequestRequestTypeDef,
    DescribeModelBiasJobDefinitionResponseTypeDef,
    DescribeModelExplainabilityJobDefinitionRequestRequestTypeDef,
    DescribeModelExplainabilityJobDefinitionResponseTypeDef,
    DescribeModelInputRequestTypeDef,
    DescribeModelOutputTypeDef,
    DescribeModelPackageGroupInputRequestTypeDef,
    DescribeModelPackageGroupOutputTypeDef,
    DescribeModelPackageInputRequestTypeDef,
    DescribeModelPackageOutputTypeDef,
    DescribeModelQualityJobDefinitionRequestRequestTypeDef,
    DescribeModelQualityJobDefinitionResponseTypeDef,
    DescribeMonitoringScheduleRequestRequestTypeDef,
    DescribeMonitoringScheduleResponseTypeDef,
    DescribeNotebookInstanceInputRequestTypeDef,
    DescribeNotebookInstanceLifecycleConfigInputRequestTypeDef,
    DescribeNotebookInstanceLifecycleConfigOutputTypeDef,
    DescribeNotebookInstanceOutputTypeDef,
    DescribePipelineDefinitionForExecutionRequestRequestTypeDef,
    DescribePipelineDefinitionForExecutionResponseTypeDef,
    DescribePipelineExecutionRequestRequestTypeDef,
    DescribePipelineExecutionResponseTypeDef,
    DescribePipelineRequestRequestTypeDef,
    DescribePipelineResponseTypeDef,
    DescribeProcessingJobRequestRequestTypeDef,
    DescribeProcessingJobResponseTypeDef,
    DescribeProjectInputRequestTypeDef,
    DescribeProjectOutputTypeDef,
    DescribeStudioLifecycleConfigRequestRequestTypeDef,
    DescribeStudioLifecycleConfigResponseTypeDef,
    DescribeSubscribedWorkteamRequestRequestTypeDef,
    DescribeSubscribedWorkteamResponseTypeDef,
    DescribeTrainingJobRequestRequestTypeDef,
    DescribeTrainingJobResponseTypeDef,
    DescribeTransformJobRequestRequestTypeDef,
    DescribeTransformJobResponseTypeDef,
    DescribeTrialComponentRequestRequestTypeDef,
    DescribeTrialComponentResponseTypeDef,
    DescribeTrialRequestRequestTypeDef,
    DescribeTrialResponseTypeDef,
    DescribeUserProfileRequestRequestTypeDef,
    DescribeUserProfileResponseTypeDef,
    DescribeWorkforceRequestRequestTypeDef,
    DescribeWorkforceResponseTypeDef,
    DescribeWorkteamRequestRequestTypeDef,
    DescribeWorkteamResponseTypeDef,
    DesiredWeightAndCapacityTypeDef,
    DeviceFleetSummaryTypeDef,
    DeviceStatsTypeDef,
    DeviceSummaryTypeDef,
    DeviceTypeDef,
    DisassociateTrialComponentRequestRequestTypeDef,
    DisassociateTrialComponentResponseTypeDef,
    DomainDetailsTypeDef,
    DomainSettingsForUpdateTypeDef,
    DomainSettingsTypeDef,
    DriftCheckBaselinesTypeDef,
    DriftCheckBiasTypeDef,
    DriftCheckExplainabilityTypeDef,
    DriftCheckModelDataQualityTypeDef,
    DriftCheckModelQualityTypeDef,
    EdgeModelStatTypeDef,
    EdgeModelSummaryTypeDef,
    EdgeModelTypeDef,
    EdgeOutputConfigTypeDef,
    EdgePackagingJobSummaryTypeDef,
    EdgePresetDeploymentOutputTypeDef,
    EdgeTypeDef,
    EndpointConfigSummaryTypeDef,
    EndpointInputConfigurationTypeDef,
    EndpointInputTypeDef,
    EndpointOutputConfigurationTypeDef,
    EndpointSummaryTypeDef,
    EndpointTypeDef,
    EnvironmentParameterRangesTypeDef,
    EnvironmentParameterTypeDef,
    ExperimentConfigTypeDef,
    ExperimentSourceTypeDef,
    ExperimentSummaryTypeDef,
    ExperimentTypeDef,
    ExplainabilityTypeDef,
    FeatureDefinitionTypeDef,
    FeatureGroupSummaryTypeDef,
    FeatureGroupTypeDef,
    FileSourceTypeDef,
    FileSystemConfigTypeDef,
    FileSystemDataSourceTypeDef,
    FilterTypeDef,
    FinalAutoMLJobObjectiveMetricTypeDef,
    FinalHyperParameterTuningJobObjectiveMetricTypeDef,
    FlowDefinitionOutputConfigTypeDef,
    FlowDefinitionSummaryTypeDef,
    GetDeviceFleetReportRequestRequestTypeDef,
    GetDeviceFleetReportResponseTypeDef,
    GetLineageGroupPolicyRequestRequestTypeDef,
    GetLineageGroupPolicyResponseTypeDef,
    GetModelPackageGroupPolicyInputRequestTypeDef,
    GetModelPackageGroupPolicyOutputTypeDef,
    GetSagemakerServicecatalogPortfolioStatusOutputTypeDef,
    GetSearchSuggestionsRequestRequestTypeDef,
    GetSearchSuggestionsResponseTypeDef,
    GitConfigForUpdateTypeDef,
    GitConfigTypeDef,
    HumanLoopActivationConditionsConfigTypeDef,
    HumanLoopActivationConfigTypeDef,
    HumanLoopConfigTypeDef,
    HumanLoopRequestSourceTypeDef,
    HumanTaskConfigTypeDef,
    HumanTaskUiSummaryTypeDef,
    HyperParameterAlgorithmSpecificationTypeDef,
    HyperParameterSpecificationTypeDef,
    HyperParameterTrainingJobDefinitionTypeDef,
    HyperParameterTrainingJobSummaryTypeDef,
    HyperParameterTuningJobConfigTypeDef,
    HyperParameterTuningJobObjectiveTypeDef,
    HyperParameterTuningJobSummaryTypeDef,
    HyperParameterTuningJobWarmStartConfigTypeDef,
    ImageConfigTypeDef,
    ImageTypeDef,
    ImageVersionTypeDef,
    InferenceExecutionConfigTypeDef,
    InferenceRecommendationTypeDef,
    InferenceRecommendationsJobTypeDef,
    InferenceSpecificationTypeDef,
    InputConfigTypeDef,
    IntegerParameterRangeSpecificationTypeDef,
    IntegerParameterRangeTypeDef,
    JupyterServerAppSettingsTypeDef,
    KernelGatewayAppSettingsTypeDef,
    KernelGatewayImageConfigTypeDef,
    KernelSpecTypeDef,
    LabelCountersForWorkteamTypeDef,
    LabelCountersTypeDef,
    LabelingJobAlgorithmsConfigTypeDef,
    LabelingJobDataAttributesTypeDef,
    LabelingJobDataSourceTypeDef,
    LabelingJobForWorkteamSummaryTypeDef,
    LabelingJobInputConfigTypeDef,
    LabelingJobOutputConfigTypeDef,
    LabelingJobOutputTypeDef,
    LabelingJobResourceConfigTypeDef,
    LabelingJobS3DataSourceTypeDef,
    LabelingJobSnsDataSourceTypeDef,
    LabelingJobStoppingConditionsTypeDef,
    LabelingJobSummaryTypeDef,
    LambdaStepMetadataTypeDef,
    LineageGroupSummaryTypeDef,
    ListActionsRequestRequestTypeDef,
    ListActionsResponseTypeDef,
    ListAlgorithmsInputRequestTypeDef,
    ListAlgorithmsOutputTypeDef,
    ListAppImageConfigsRequestRequestTypeDef,
    ListAppImageConfigsResponseTypeDef,
    ListAppsRequestRequestTypeDef,
    ListAppsResponseTypeDef,
    ListArtifactsRequestRequestTypeDef,
    ListArtifactsResponseTypeDef,
    ListAssociationsRequestRequestTypeDef,
    ListAssociationsResponseTypeDef,
    ListAutoMLJobsRequestRequestTypeDef,
    ListAutoMLJobsResponseTypeDef,
    ListCandidatesForAutoMLJobRequestRequestTypeDef,
    ListCandidatesForAutoMLJobResponseTypeDef,
    ListCodeRepositoriesInputRequestTypeDef,
    ListCodeRepositoriesOutputTypeDef,
    ListCompilationJobsRequestRequestTypeDef,
    ListCompilationJobsResponseTypeDef,
    ListContextsRequestRequestTypeDef,
    ListContextsResponseTypeDef,
    ListDataQualityJobDefinitionsRequestRequestTypeDef,
    ListDataQualityJobDefinitionsResponseTypeDef,
    ListDeviceFleetsRequestRequestTypeDef,
    ListDeviceFleetsResponseTypeDef,
    ListDevicesRequestRequestTypeDef,
    ListDevicesResponseTypeDef,
    ListDomainsRequestRequestTypeDef,
    ListDomainsResponseTypeDef,
    ListEdgePackagingJobsRequestRequestTypeDef,
    ListEdgePackagingJobsResponseTypeDef,
    ListEndpointConfigsInputRequestTypeDef,
    ListEndpointConfigsOutputTypeDef,
    ListEndpointsInputRequestTypeDef,
    ListEndpointsOutputTypeDef,
    ListExperimentsRequestRequestTypeDef,
    ListExperimentsResponseTypeDef,
    ListFeatureGroupsRequestRequestTypeDef,
    ListFeatureGroupsResponseTypeDef,
    ListFlowDefinitionsRequestRequestTypeDef,
    ListFlowDefinitionsResponseTypeDef,
    ListHumanTaskUisRequestRequestTypeDef,
    ListHumanTaskUisResponseTypeDef,
    ListHyperParameterTuningJobsRequestRequestTypeDef,
    ListHyperParameterTuningJobsResponseTypeDef,
    ListImageVersionsRequestRequestTypeDef,
    ListImageVersionsResponseTypeDef,
    ListImagesRequestRequestTypeDef,
    ListImagesResponseTypeDef,
    ListInferenceRecommendationsJobsRequestRequestTypeDef,
    ListInferenceRecommendationsJobsResponseTypeDef,
    ListLabelingJobsForWorkteamRequestRequestTypeDef,
    ListLabelingJobsForWorkteamResponseTypeDef,
    ListLabelingJobsRequestRequestTypeDef,
    ListLabelingJobsResponseTypeDef,
    ListLineageGroupsRequestRequestTypeDef,
    ListLineageGroupsResponseTypeDef,
    ListModelBiasJobDefinitionsRequestRequestTypeDef,
    ListModelBiasJobDefinitionsResponseTypeDef,
    ListModelExplainabilityJobDefinitionsRequestRequestTypeDef,
    ListModelExplainabilityJobDefinitionsResponseTypeDef,
    ListModelMetadataRequestRequestTypeDef,
    ListModelMetadataResponseTypeDef,
    ListModelPackageGroupsInputRequestTypeDef,
    ListModelPackageGroupsOutputTypeDef,
    ListModelPackagesInputRequestTypeDef,
    ListModelPackagesOutputTypeDef,
    ListModelQualityJobDefinitionsRequestRequestTypeDef,
    ListModelQualityJobDefinitionsResponseTypeDef,
    ListModelsInputRequestTypeDef,
    ListModelsOutputTypeDef,
    ListMonitoringExecutionsRequestRequestTypeDef,
    ListMonitoringExecutionsResponseTypeDef,
    ListMonitoringSchedulesRequestRequestTypeDef,
    ListMonitoringSchedulesResponseTypeDef,
    ListNotebookInstanceLifecycleConfigsInputRequestTypeDef,
    ListNotebookInstanceLifecycleConfigsOutputTypeDef,
    ListNotebookInstancesInputRequestTypeDef,
    ListNotebookInstancesOutputTypeDef,
    ListPipelineExecutionStepsRequestRequestTypeDef,
    ListPipelineExecutionStepsResponseTypeDef,
    ListPipelineExecutionsRequestRequestTypeDef,
    ListPipelineExecutionsResponseTypeDef,
    ListPipelineParametersForExecutionRequestRequestTypeDef,
    ListPipelineParametersForExecutionResponseTypeDef,
    ListPipelinesRequestRequestTypeDef,
    ListPipelinesResponseTypeDef,
    ListProcessingJobsRequestRequestTypeDef,
    ListProcessingJobsResponseTypeDef,
    ListProjectsInputRequestTypeDef,
    ListProjectsOutputTypeDef,
    ListStudioLifecycleConfigsRequestRequestTypeDef,
    ListStudioLifecycleConfigsResponseTypeDef,
    ListSubscribedWorkteamsRequestRequestTypeDef,
    ListSubscribedWorkteamsResponseTypeDef,
    ListTagsInputRequestTypeDef,
    ListTagsOutputTypeDef,
    ListTrainingJobsForHyperParameterTuningJobRequestRequestTypeDef,
    ListTrainingJobsForHyperParameterTuningJobResponseTypeDef,
    ListTrainingJobsRequestRequestTypeDef,
    ListTrainingJobsResponseTypeDef,
    ListTransformJobsRequestRequestTypeDef,
    ListTransformJobsResponseTypeDef,
    ListTrialComponentsRequestRequestTypeDef,
    ListTrialComponentsResponseTypeDef,
    ListTrialsRequestRequestTypeDef,
    ListTrialsResponseTypeDef,
    ListUserProfilesRequestRequestTypeDef,
    ListUserProfilesResponseTypeDef,
    ListWorkforcesRequestRequestTypeDef,
    ListWorkforcesResponseTypeDef,
    ListWorkteamsRequestRequestTypeDef,
    ListWorkteamsResponseTypeDef,
    MemberDefinitionTypeDef,
    MetadataPropertiesTypeDef,
    MetricDataTypeDef,
    MetricDatumTypeDef,
    MetricDefinitionTypeDef,
    MetricsSourceTypeDef,
    ModelArtifactsTypeDef,
    ModelBiasAppSpecificationTypeDef,
    ModelBiasBaselineConfigTypeDef,
    ModelBiasJobInputTypeDef,
    ModelClientConfigTypeDef,
    ModelConfigurationTypeDef,
    ModelDataQualityTypeDef,
    ModelDeployConfigTypeDef,
    ModelDeployResultTypeDef,
    ModelDigestsTypeDef,
    ModelExplainabilityAppSpecificationTypeDef,
    ModelExplainabilityBaselineConfigTypeDef,
    ModelExplainabilityJobInputTypeDef,
    ModelInputTypeDef,
    ModelLatencyThresholdTypeDef,
    ModelMetadataFilterTypeDef,
    ModelMetadataSearchExpressionTypeDef,
    ModelMetadataSummaryTypeDef,
    ModelMetricsTypeDef,
    ModelPackageContainerDefinitionTypeDef,
    ModelPackageGroupSummaryTypeDef,
    ModelPackageGroupTypeDef,
    ModelPackageStatusDetailsTypeDef,
    ModelPackageStatusItemTypeDef,
    ModelPackageSummaryTypeDef,
    ModelPackageTypeDef,
    ModelPackageValidationProfileTypeDef,
    ModelPackageValidationSpecificationTypeDef,
    ModelQualityAppSpecificationTypeDef,
    ModelQualityBaselineConfigTypeDef,
    ModelQualityJobInputTypeDef,
    ModelQualityTypeDef,
    ModelStepMetadataTypeDef,
    ModelSummaryTypeDef,
    MonitoringAppSpecificationTypeDef,
    MonitoringBaselineConfigTypeDef,
    MonitoringClusterConfigTypeDef,
    MonitoringConstraintsResourceTypeDef,
    MonitoringExecutionSummaryTypeDef,
    MonitoringGroundTruthS3InputTypeDef,
    MonitoringInputTypeDef,
    MonitoringJobDefinitionSummaryTypeDef,
    MonitoringJobDefinitionTypeDef,
    MonitoringNetworkConfigTypeDef,
    MonitoringOutputConfigTypeDef,
    MonitoringOutputTypeDef,
    MonitoringResourcesTypeDef,
    MonitoringS3OutputTypeDef,
    MonitoringScheduleConfigTypeDef,
    MonitoringScheduleSummaryTypeDef,
    MonitoringScheduleTypeDef,
    MonitoringStatisticsResourceTypeDef,
    MonitoringStoppingConditionTypeDef,
    MultiModelConfigTypeDef,
    NeoVpcConfigTypeDef,
    NestedFiltersTypeDef,
    NetworkConfigTypeDef,
    NotebookInstanceLifecycleConfigSummaryTypeDef,
    NotebookInstanceLifecycleHookTypeDef,
    NotebookInstanceSummaryTypeDef,
    NotificationConfigurationTypeDef,
    ObjectiveStatusCountersTypeDef,
    OfflineStoreConfigTypeDef,
    OfflineStoreStatusTypeDef,
    OidcConfigForResponseTypeDef,
    OidcConfigTypeDef,
    OidcMemberDefinitionTypeDef,
    OnlineStoreConfigTypeDef,
    OnlineStoreSecurityConfigTypeDef,
    OutputConfigTypeDef,
    OutputDataConfigTypeDef,
    OutputParameterTypeDef,
    PaginatorConfigTypeDef,
    ParameterRangeTypeDef,
    ParameterRangesTypeDef,
    ParameterTypeDef,
    ParentHyperParameterTuningJobTypeDef,
    ParentTypeDef,
    PendingDeploymentSummaryTypeDef,
    PendingProductionVariantSummaryTypeDef,
    PhaseTypeDef,
    PipelineExecutionStepMetadataTypeDef,
    PipelineExecutionStepTypeDef,
    PipelineExecutionSummaryTypeDef,
    PipelineExecutionTypeDef,
    PipelineExperimentConfigTypeDef,
    PipelineSummaryTypeDef,
    PipelineTypeDef,
    ProcessingClusterConfigTypeDef,
    ProcessingFeatureStoreOutputTypeDef,
    ProcessingInputTypeDef,
    ProcessingJobStepMetadataTypeDef,
    ProcessingJobSummaryTypeDef,
    ProcessingJobTypeDef,
    ProcessingOutputConfigTypeDef,
    ProcessingOutputTypeDef,
    ProcessingResourcesTypeDef,
    ProcessingS3InputTypeDef,
    ProcessingS3OutputTypeDef,
    ProcessingStoppingConditionTypeDef,
    ProductionVariantCoreDumpConfigTypeDef,
    ProductionVariantServerlessConfigTypeDef,
    ProductionVariantStatusTypeDef,
    ProductionVariantSummaryTypeDef,
    ProductionVariantTypeDef,
    ProfilerConfigForUpdateTypeDef,
    ProfilerConfigTypeDef,
    ProfilerRuleConfigurationTypeDef,
    ProfilerRuleEvaluationStatusTypeDef,
    ProjectSummaryTypeDef,
    ProjectTypeDef,
    PropertyNameQueryTypeDef,
    PropertyNameSuggestionTypeDef,
    ProvisioningParameterTypeDef,
    PublicWorkforceTaskPriceTypeDef,
    PutModelPackageGroupPolicyInputRequestTypeDef,
    PutModelPackageGroupPolicyOutputTypeDef,
    QualityCheckStepMetadataTypeDef,
    QueryFiltersTypeDef,
    QueryLineageRequestRequestTypeDef,
    QueryLineageResponseTypeDef,
    RStudioServerProAppSettingsTypeDef,
    RStudioServerProDomainSettingsForUpdateTypeDef,
    RStudioServerProDomainSettingsTypeDef,
    RecommendationJobInputConfigTypeDef,
    RecommendationJobResourceLimitTypeDef,
    RecommendationJobStoppingConditionsTypeDef,
    RecommendationMetricsTypeDef,
    RedshiftDatasetDefinitionTypeDef,
    RegisterDevicesRequestRequestTypeDef,
    RegisterModelStepMetadataTypeDef,
    RenderUiTemplateRequestRequestTypeDef,
    RenderUiTemplateResponseTypeDef,
    RenderableTaskTypeDef,
    RenderingErrorTypeDef,
    RepositoryAuthConfigTypeDef,
    ResolvedAttributesTypeDef,
    ResourceConfigTypeDef,
    ResourceLimitsTypeDef,
    ResourceSpecTypeDef,
    ResponseMetadataTypeDef,
    RetentionPolicyTypeDef,
    RetryPipelineExecutionRequestRequestTypeDef,
    RetryPipelineExecutionResponseTypeDef,
    RetryStrategyTypeDef,
    S3DataSourceTypeDef,
    S3StorageConfigTypeDef,
    ScheduleConfigTypeDef,
    SearchExpressionTypeDef,
    SearchRecordTypeDef,
    SearchRequestRequestTypeDef,
    SearchResponseTypeDef,
    SecondaryStatusTransitionTypeDef,
    SendPipelineExecutionStepFailureRequestRequestTypeDef,
    SendPipelineExecutionStepFailureResponseTypeDef,
    SendPipelineExecutionStepSuccessRequestRequestTypeDef,
    SendPipelineExecutionStepSuccessResponseTypeDef,
    ServiceCatalogProvisionedProductDetailsTypeDef,
    ServiceCatalogProvisioningDetailsTypeDef,
    ServiceCatalogProvisioningUpdateDetailsTypeDef,
    SharingSettingsTypeDef,
    ShuffleConfigTypeDef,
    SourceAlgorithmSpecificationTypeDef,
    SourceAlgorithmTypeDef,
    SourceIpConfigTypeDef,
    StartMonitoringScheduleRequestRequestTypeDef,
    StartNotebookInstanceInputRequestTypeDef,
    StartPipelineExecutionRequestRequestTypeDef,
    StartPipelineExecutionResponseTypeDef,
    StopAutoMLJobRequestRequestTypeDef,
    StopCompilationJobRequestRequestTypeDef,
    StopEdgePackagingJobRequestRequestTypeDef,
    StopHyperParameterTuningJobRequestRequestTypeDef,
    StopInferenceRecommendationsJobRequestRequestTypeDef,
    StopLabelingJobRequestRequestTypeDef,
    StopMonitoringScheduleRequestRequestTypeDef,
    StopNotebookInstanceInputRequestTypeDef,
    StopPipelineExecutionRequestRequestTypeDef,
    StopPipelineExecutionResponseTypeDef,
    StopProcessingJobRequestRequestTypeDef,
    StopTrainingJobRequestRequestTypeDef,
    StopTransformJobRequestRequestTypeDef,
    StoppingConditionTypeDef,
    StudioLifecycleConfigDetailsTypeDef,
    SubscribedWorkteamTypeDef,
    SuggestionQueryTypeDef,
    TagTypeDef,
    TargetPlatformTypeDef,
    TensorBoardAppSettingsTypeDef,
    TensorBoardOutputConfigTypeDef,
    TrafficPatternTypeDef,
    TrafficRoutingConfigTypeDef,
    TrainingJobDefinitionTypeDef,
    TrainingJobStatusCountersTypeDef,
    TrainingJobStepMetadataTypeDef,
    TrainingJobSummaryTypeDef,
    TrainingJobTypeDef,
    TrainingSpecificationTypeDef,
    TransformDataSourceTypeDef,
    TransformInputTypeDef,
    TransformJobDefinitionTypeDef,
    TransformJobStepMetadataTypeDef,
    TransformJobSummaryTypeDef,
    TransformJobTypeDef,
    TransformOutputTypeDef,
    TransformResourcesTypeDef,
    TransformS3DataSourceTypeDef,
    TrialComponentArtifactTypeDef,
    TrialComponentMetricSummaryTypeDef,
    TrialComponentParameterValueTypeDef,
    TrialComponentSimpleSummaryTypeDef,
    TrialComponentSourceDetailTypeDef,
    TrialComponentSourceTypeDef,
    TrialComponentStatusTypeDef,
    TrialComponentSummaryTypeDef,
    TrialComponentTypeDef,
    TrialSourceTypeDef,
    TrialSummaryTypeDef,
    TrialTypeDef,
    TuningJobCompletionCriteriaTypeDef,
    TuningJobStepMetaDataTypeDef,
    USDTypeDef,
    UiConfigTypeDef,
    UiTemplateInfoTypeDef,
    UiTemplateTypeDef,
    UpdateActionRequestRequestTypeDef,
    UpdateActionResponseTypeDef,
    UpdateAppImageConfigRequestRequestTypeDef,
    UpdateAppImageConfigResponseTypeDef,
    UpdateArtifactRequestRequestTypeDef,
    UpdateArtifactResponseTypeDef,
    UpdateCodeRepositoryInputRequestTypeDef,
    UpdateCodeRepositoryOutputTypeDef,
    UpdateContextRequestRequestTypeDef,
    UpdateContextResponseTypeDef,
    UpdateDeviceFleetRequestRequestTypeDef,
    UpdateDevicesRequestRequestTypeDef,
    UpdateDomainRequestRequestTypeDef,
    UpdateDomainResponseTypeDef,
    UpdateEndpointInputRequestTypeDef,
    UpdateEndpointOutputTypeDef,
    UpdateEndpointWeightsAndCapacitiesInputRequestTypeDef,
    UpdateEndpointWeightsAndCapacitiesOutputTypeDef,
    UpdateExperimentRequestRequestTypeDef,
    UpdateExperimentResponseTypeDef,
    UpdateImageRequestRequestTypeDef,
    UpdateImageResponseTypeDef,
    UpdateModelPackageInputRequestTypeDef,
    UpdateModelPackageOutputTypeDef,
    UpdateMonitoringScheduleRequestRequestTypeDef,
    UpdateMonitoringScheduleResponseTypeDef,
    UpdateNotebookInstanceInputRequestTypeDef,
    UpdateNotebookInstanceLifecycleConfigInputRequestTypeDef,
    UpdatePipelineExecutionRequestRequestTypeDef,
    UpdatePipelineExecutionResponseTypeDef,
    UpdatePipelineRequestRequestTypeDef,
    UpdatePipelineResponseTypeDef,
    UpdateProjectInputRequestTypeDef,
    UpdateProjectOutputTypeDef,
    UpdateTrainingJobRequestRequestTypeDef,
    UpdateTrainingJobResponseTypeDef,
    UpdateTrialComponentRequestRequestTypeDef,
    UpdateTrialComponentResponseTypeDef,
    UpdateTrialRequestRequestTypeDef,
    UpdateTrialResponseTypeDef,
    UpdateUserProfileRequestRequestTypeDef,
    UpdateUserProfileResponseTypeDef,
    UpdateWorkforceRequestRequestTypeDef,
    UpdateWorkforceResponseTypeDef,
    UpdateWorkteamRequestRequestTypeDef,
    UpdateWorkteamResponseTypeDef,
    UserContextTypeDef,
    UserProfileDetailsTypeDef,
    UserSettingsTypeDef,
    VariantPropertyTypeDef,
    VertexTypeDef,
    VpcConfigTypeDef,
    WaiterConfigTypeDef,
    WorkforceTypeDef,
    WorkteamTypeDef,
)

def get_structure() -> ActionSourceTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`types-aiobotocore-sagemaker` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[types-aiobotocore-sagemaker docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
